import { AsyncData, AsyncDataOptions } from 'nuxt/app';
/**
 * Type alias for the result returned by useAsyncData.
 * @template T - The type of the data returned by the function.
 */
type AsyncDataResult<T> = AsyncData<T, Error>;
/**
 * Transforms an object's Promise-returning functions into functions compatible with useAsyncData.
 *
 * For each function in the object:
 * - If the function returns a Promise and takes no arguments, it becomes a function that accepts optional AsyncDataOptions.
 * - If the function returns a Promise and takes arguments, it becomes a function that accepts an argsSupplier and optional AsyncDataOptions.
 *
 * This allows you to use the functions within a Nuxt application, leveraging the reactivity and data fetching capabilities of useAsyncData.
 *
 * @template T - The type of the object.
 */
export type AsyncDataWrapper<T> = {
    [K in keyof T]: T[K] extends (...args: infer Args) => Promise<infer R> ? Args extends [] ? (options?: AsyncDataOptions<R>) => AsyncDataResult<R> : (argsSupplier: () => Args, options?: AsyncDataOptions<R>) => AsyncDataResult<R> : never;
};
/**
 * Wraps an object's Promise-returning functions to integrate with Nuxt's useAsyncData.
 *
 * It transforms the functions of the provided object into functions that can be used within a Nuxt application,
 * leveraging the reactivity and data fetching capabilities of useAsyncData.
 *
 * @template T - The type of the object.
 * @param obj - The object containing functions that return Promises.
 * @returns An object with the same function names as the original object, but wrapped to work with useAsyncData.
 *
 * @example
 * ```typescript
 * const originalObject = {
 *   async fetchData() { ... },
 *   async getItem(id: number) { ... },
 * };
 * const wrappedObject = useAsyncDataWrapper(originalObject);
 * ```
 */
export declare function useAsyncDataWrapper<T extends Record<string, any>>(obj: T): AsyncDataWrapper<T>;
export {};
